from embedding.tokenizer import Tokenizer


def test_whitespace_tokenizer(whitespace_tokenizer: Tokenizer) -> None:
    assert len(whitespace_tokenizer.tokenize('გიორგი მიდის   სახლში')) == 3
    assert whitespace_tokenizer.tokenize('გიორგი   მიდის სახლში') == ['გიორგი', 'მიდის', 'სახლში']
    assert len(whitespace_tokenizer.tokenize('გიორგი მიდის სახლში.')) == 3
    assert whitespace_tokenizer.tokenize('გიორგი მიდის სახლში.') == ['გიორგი', 'მიდის', 'სახლში.']
    assert len(whitespace_tokenizer.tokenize('გიორგი, მიდი სახლში.')) == 3
    assert whitespace_tokenizer.tokenize('გიორგი, მიდი სახლში.') == ['გიორგი,', 'მიდი', 'სახლში.']


def test_basic_tokenizer(basic_tokenizer: Tokenizer) -> None:
    assert len(basic_tokenizer.tokenize('გიორგი მიდის   სახლში')) == 3
    assert basic_tokenizer.tokenize('გიორგი   მიდის სახლში') == ['გიორგი', 'მიდის', 'სახლში']
    assert len(basic_tokenizer.tokenize('გიორგი მიდის სახლში.')) == 4
    assert basic_tokenizer.tokenize('გიორგი მიდის სახლში.') == ['გიორგი', 'მიდის', 'სახლში', '.']
    assert len(basic_tokenizer.tokenize('გიორგი, მიდი სახლში.')) == 5
    assert basic_tokenizer.tokenize('გიორგი, მიდი სახლში.') == ['გიორგი', ',', 'მიდი', 'სახლში', '.']
    assert basic_tokenizer.tokenize('გიორგი, მიდი სახლ-კარში.') == ['გიორგი', ',', 'მიდი', 'სახლ-კარში', '.']
    assert basic_tokenizer.tokenize('გიორგი ცხოვრობდა მე-15 საუკუნეში?!') == ['გიორგი', 'ცხოვრობდა', 'მე-15',
                                                                              'საუკუნეში', '?!']


def test_basic_tokenizer_with_number_substitution(basic_tokenizer_with_number_replacement: Tokenizer) -> None:
    assert basic_tokenizer_with_number_replacement.tokenize('გიორგი '
                                                            'ცხოვრობდა '
                                                            'მე-15 '
                                                            'საუკუნეში?!') == ['გიორგი', 'ცხოვრობდა', 'მე-<NUM>',
                                                                               'საუკუნეში', '?!']
    assert basic_tokenizer_with_number_replacement.tokenize('მე '
                                                            'მაქვს '
                                                            '35 '
                                                            'ვაშლი.') == ['მე', 'მაქვს', '<NUM>',
                                                                          'ვაშლი', '.']



import pytest

from embedding.model import Word2VecModel
from embedding.tokenizer import Tokenizer, WhitespaceTokenizer, BasicTokenizer, NumSubTokenizer, Word2VecTokenizer


@pytest.fixture
def whitespace_tokenizer() -> Tokenizer:
    return WhitespaceTokenizer()


@pytest.fixture
def basic_tokenizer() -> Tokenizer:
    return BasicTokenizer()


@pytest.fixture
def basic_tokenizer_with_number_replacement() -> Tokenizer:
    return NumSubTokenizer()


@pytest.fixture
def word2vec_tokenizer() -> Tokenizer:
    return Word2VecTokenizer()

@pytest.fixture
def word2vec() -> Word2VecModel:
    return Word2VecModel()



from embedding.model import Word2VecModel
import numpy as np

from embedding.tokenizer import Tokenizer


def test_out_of_vocabulary_word2vec(word2vec: Word2VecModel) -> None:
    vec = word2vec("NOT IN A DICTIONARY")
    assert vec == np.zeros(vec.shape)


def test_sentence_word2vec(word2vec: Word2VecModel, word2vec_tokenizer: Tokenizer) -> None:
    sentence = "მე მივდივარ სახლში"
    assert all([all(word2vec(word) != np.zeros(word2vec(word).shape)) for word in word2vec_tokenizer.tokenize(sentence)])
    sentence = "მე მაქვს 5 ვაშლი"
    assert all(
        [all(word2vec(word) != np.zeros(word2vec(word).shape)) for word in word2vec_tokenizer.tokenize(sentence)])

